# ns3-extended

## Introduction

This module facilitates the creation of NS3 programs by providing standard templates for various types of programs. The templates are numbered , simplifying the process of writing NS3 programs.

## Installation

To install `ns3-extended`, you can use pip:

```bash
pip install ns3-extended==0.0.5
```
